<?php
namespace Estoque\Entities;



use \Geral\Util\DateUtil;
use \Geral\Entities\Produto;
use \Geral\Entities\Localestoque;
USE \Geral\Entities\Paramfilial;

/**
 *
 * @method Itlanctoest findOneByCdfilialAndNrlancestqAndCdprodutoAndNrorg($cdfilial, $nrlanctoest, $cdproduto, $nrorg) static
 * @method array findByCdfilialAndNrlancestqAndNrorg($cdfilial, $nrlanctoestoq, $nrorg) static
 * @method array findOneByCdprodutoAndNrlancestqAndCdfilialAndNrorg($cdprodesto, $nrlanctoestoq, $cdfilial, $nrorg) static
 *
 */
/**
 * @method Itlanctoest findOneByCdfilialAndNrlancestqAndNrorg($cdfilial, $nrlancest, $nrorg) static
 * @method Itlanctoest findOneByCdfilialAndNrlancestqAndCdprodutoAndNrorg($Cdfilial, $Nrlancestq, $Cdproduto, $Nrorg) static
 */
class Itlanctoest extends Base\Itlanctoest
{
    /** sha1('SUBSTITUICAO_ESPACO') */
    const SUBSTITUICAO_ESPACO = 'de6f39b57e42856dcb9f1e7d2cc0911066722ea6';
    /**
     * Constante para IDEVOLESTOQ = "S".
     */
    const ESTOQUE_EVOLUIDO     = "S";
    /**
     * Constate para IDEVOLESTOQ = "N".
     */
    const ESTOQUE_NAO_EVOLUIDO = "N";
    /**
     * Constate para IDORDEMCLC = "U".
     */
    const ORDEM_ULTIMO         = "U";
    /**
     * Constate para IDORDEMCLC = "0".
     */
    const ORDEM_PRIMEIRO       = "0";
    /**
     * Constate para IDTIPOMOVI = "0".
     */
    const TIPO_IMPLANTACAO     = "0";
    /**
     * Constate para IDTIPOMOVI = "1".
     */
    const TIPO_AJUSTE = "1";
    /**
     * Constate para IDTIPOMOVI = "2".
     */
    const TIPO_ENTRADA         = "2";
    /**
     * Constate para IDTIPOMOVI = "3".
     */
    const TIPO_RETIRADA       = "3";
    /**
     * Constate para IDTIPOMOVI = "4".
     */
    const TIPO_SAIDA       = "4";
    /**
     * Constate para IDTIPOMOVI = "5".
     */
    const TIPO_DEVOLUCAO       = "5";

    CONST SIM = 'S';
    CONST NAO = 'N';


    /**
     * Atualiza id de evolucao do item para todos os itens de um lancamento de estoque, identificados por uma NF.
     *
     * @static
     * @param \Estoque\Entities\Lanctoestoq $lanctoestoq
     * @param $idevolucao
     */
    public static function atualizaEvolucaoDeEstoqueTodosProdutos(Lanctoestoq $lanctoestoq, $idevolucao) {
        $itensEstoque = self::findByCdfilialAndNrlancestqAndNrorg (
            $lanctoestoq->getFilial()->getCdfilial(),
            $lanctoestoq->getNrlancestq(),
            \Geral\Util\Ambiente::getNrorg()
        );

        /** @var $itemEstoque  Itlanctoest */
        foreach ($itensEstoque as $itemEstoque) {
            $itemEstoque->atualizaEvolucaoDeEstoque($idevolucao);
        }
    }

    /**
     * Atualiza o id de evolucao do item de estoque.
     *
     * @param string $idEvolucao
     */
    public function atualizaEvolucaoDeEstoque($idEvolucao) {
        $this->setIdevolestoq($idEvolucao);
        $this->persist();
    }


    public function verificaMovimentacaoEvoluida(
        $filial, $cdProduto, $almox, $local, $lote, $subLote, $dtLanc, $ordem, $tpMovi, $nrorg
    ){
//        $dtLancto = DateUtil::getDataDeString($dtLanc);

        $listaItens = self::getObjectsByWhere(
            'CDFILIMOVI = ? AND CDPRODMOVI = ? AND CDALMOXARIFE = ? AND CDLOCALESTOQ = ? AND NRLOTEESTQ = ? AND
            NRSUBLOTE = ? AND DTLANCMOVI = ? AND (IDORDEMCLC = ? OR IDORDEMCLC IS NULL) AND
            (IDEVOLESTOQ = ? OR IDEVOLESTOQ IS NULL) AND IDTIPOMOVI = ? AND NRORG = ?',
            array(
                $filial, $cdProduto, $almox, $local, $lote, $subLote, $dtLanc,
                $ordem, self::ESTOQUE_EVOLUIDO, $tpMovi, $nrorg
            )
        );

        return $listaItens;
    }


    public function atualizaDadosProduto(
        $cdFilial, $cdProduto, $qtProduto, $vrTotal, $vrLiq, $vrBruto, $qtEstoq, $vrEstoq, $nrorg, $operAtual
    ) {
        $dtInclusao = DateUtil::getDataAtual();

        /** @var $dadoProd Produto */
        $dadoProd = Produto::getObject(array('nrorg' => $nrorg, 'cdfilial' => $cdFilial, 'cdproduto' => $cdProduto));
        $cdProdEsto = $dadoProd->getCdprodesto();

        $this->setCdproduto($cdProduto);
        $this->setCdprodmovi($cdProdEsto);
        $this->setQtlanctoest($qtEstoq);
        $this->setQttotlancto($qtProduto);
        $this->setVrunilancto($vrLiq);
        $this->setVrlanctobrut($vrBruto);
        $this->setVrtotlancto($vrTotal);
        $this->setVrlanctoest($vrEstoq);
        $this->setDtultatu($dtInclusao);
        $this->setNrorgultatu($nrorg);
        $this->setCdoperultatu($operAtual);

        $this->persist();
        return $this;
    }


    /**
     * Insere novo item de lancamento.
     *
     * @param $filial
     * @param $nrorg
     * @param $nrLanc
     * @param $dtLancto
     * @param $cdProduto
     * @param $local
     * @param $cdAlmox
     * @param $operador
     * @param $idEvol
     * @param $ordem
     * @param $tipoMovi
     * @param $qtEstoq
     * @param $qtProduto
     * @param $seq
     * @param $subLote
     * @param $lote
     * @param $vrLanctoBruto
     * @param $vrLiq
     * @param $vrTotal
     *
     * @return Itlanctoest
     */
    public function insereItemLancto(
            $filial, $nrorg, $nrLanc, $dtLancto, $cdProduto, $local, $cdAlmox, $operador,
            $idEvol, $ordem, $tipoMovi, $qtEstoq, $vrEstq, $qtProduto, $seq, $subLote, $lote, $vrLanctoBruto,
            $vrLiq, $vrTotal
    ){
        $dtAtual = DateUtil::getDataAtual();
        if (is_object($dtLancto) === false) {
            list($dtLancto) = explode(' ', $dtLancto);
            $dtLancto = DateUtil::getDataDeString($dtLancto);
        }
        $dtLancto = DateUtil::truncateData($dtLancto);

        /** @var $objLancto Lanctoestoq */
        $objLancto = Lanctoestoq::getObject(array('cdfilial' => $filial, 'nrorg' => $nrorg, 'nrlancestq' => $nrLanc));
        /** @var $objProd Produto */
        $objProd = Produto::getObject(array('cdproduto' => $cdProduto, 'nrorg' => $nrorg));
        $prodMovi = $objProd->getCdprodesto();
        if (empty($prodMovi) === true) {
            $prodMovi = $objProd->getCdproduto();
        }
        /** @var $objProdesto Produto */
        $objProdesto = Produto::getObject(array('cdproduto' => $prodMovi, 'nrorg' => $nrorg));
        /** @var $objLocal Localestoque */
        $objLocal = Localestoque::getObject(array('cdfilial' => $filial, 'nrorg' => $nrorg, 'cdlocalestoq' => $local, 'cdalmoxarife' => $cdAlmox));
        if($objLocal == true){
            $this->setLocalestoq($objLocal);
        }
        else{
        	$this->setCdalmoxarife($cdAlmox);
        	$this->setCdfilimovi($filial);
        	$this->setCdlocalestoq($local);
        	$this->setNrorg($nrorg);
            
        }
        
        $this->setCdfilial($filial);
        $this->setCdfilimovi($filial);
        $this->setCdoperador($operador);
        $this->setDtlancmovi($dtLancto);
        $this->setDtinclusao($dtAtual);
        $this->setIdevolestoq($idEvol);
        $this->setIdordemclc($ordem);
        $this->setIdtipomovi($tipoMovi);
        $this->setQtlanctoest($qtEstoq);
        $this->setQttotlancto($qtProduto);
        $this->setLancestq($objLancto);
        $this->setNrsequitem($seq);
        $this->setNrsublote($subLote);
        $this->setNrloteestq($lote);
        $this->setProdmovi($objProdesto);
        $this->setProduto($objProd);
        $this->setVrlanctobrut($vrLanctoBruto == true ? $vrLanctoBruto : 0);
        $this->setVrunilancto($vrLiq == true ? $vrLiq : 0);
        $this->setVrtotlancto($vrTotal == true ? $vrLanctoBruto : 0);
        $this->setVrlanctoest($vrEstq);
        $this->setIdaltcmedmv('N');
        $this->setCdoperinclusao($operador);
        $this->setDtultatu($dtAtual);
        
        $paramfilial = Paramfilial::findOneByCdfilial($filial);
        if ($paramfilial->getIdgeraretaju() == 'P' or $paramfilial->getIdgeraretaju() == null)
            $this->setIdordemclc(0);
        else
            $this->setIdordemclc('U');   
     
        
        $this->persist();

        return $this;

    }


    public static function consultaItens($filial, $nrLancto, $nrorg){
        /** @var $objItens  */
        $objItens = Itlanctoest::getObjectsByWhere(
            'CDFILIAL = ? AND NRLANCESTQ = ? AND NRORG = ?',
            array($filial, $nrLancto, $nrorg)
        );

        return $objItens;
    }


    public static function consultaItem($filial, $nrLancto, $nrorg, $seq){
        /** @var $objItem Itlanctoest */
//        $objItem = Itlanctoest::getObject(
//            array('cdfilial' => $filial, 'nrlancestq' => $nrLancto, 'nrsequitem' => $seq, 'nrorg' => $nrorg)
//        );
        $objItem = Itlanctoest::getObjectByWhere(
            'CDFILIAL = ? AND NRLANCESTQ = ?  AND NRSEQUITEM = ? AND NRORG = ?',
            array($filial, $nrLancto, $seq, $nrorg)
        );

        return $objItem;
    }


}