/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/*                                                                            */
/* Compras e Suprimentos                                                      */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Nome: LIMPA_CMPSUP                                                         */
/*                                                                            */
/* Descrio:                                                                 */
/* Limpa as informaes de Solcitao de Compras,                             */
/* Cotao de Preos ou AF                                                    */
/*                                                                            */
/*                                                                            */
/* Criao(ORACLE):                                                           */
/* 24/01/2000 - Yoris L. de Souza                                             */
/*                                                                            */
/* Converso:                                                                 */
/* 07/05/2001 - Romero Lucas Bicalho                                          */
/*                                                                            */
/* @C:\WIN_PRJ\SQL\SQLSERVER\8280_CMPSTP_LIMPA_CMPSUP.SQL                     */
/*                                                                            */
/******************************************************************************/
/******************************************************************************/
/* PARAMETROS:                                                                */
/*                                                                            */
/******************************************************************************/
IF EXISTS (SELECT * FROM sysobjects O, sysusers U
          WHERE
            o.name = 'LIMPA_CMPSUP'  and
            type = 'P'                  and
            u.uid = o.uid               and
            u.name = USER)
   DROP PROCEDURE LIMPA_CMPSUP;
GO
CREATE PROCEDURE LIMPA_CMPSUP
(
   @P_CDCENTCMP    VARCHAR(04),
   @P_CDFILLISTA   VARCHAR(04),
   @P_TCDFILIAL    VARCHAR(01),
   @P_IDLIMPSOL    VARCHAR(01),
   @P_IDLIMPCOL    VARCHAR(01),
   @P_IDLIMPAF     VARCHAR(01),
   @P_DTLIMPSOL    DATETIME,         /* LIMPA A SOLICITAAO */
   @P_DTLIMPCOT    DATETIME,         /* LIMPA A COTAAO     */
   @P_DTLIMPAF     DATETIME,         /* LIMPA A AUTORIZAAO */
   @P_DSSISTEMA    VARCHAR(60),      /* NOME DO SISTEMA */
   @P_NMOPERADOR   VARCHAR(40),      /* NOME DO OPERADOR */
   @P_DSLIMPSOL    VARCHAR(500),     /* TIPO DE OPERAAO _ SOLICITAAO */
   @P_DSLIMPCOT    VARCHAR(500),     /* TIPO DE OPERAAO _ COTAAO */
   @P_DSLIMPAF     VARCHAR(500),     /* TIPO DE OPERAAO _ AUTORIZAAO */
   @P_IDLIMPOU     VARCHAR(01) OUTPUT)
AS
   DECLARE @V_IDLIMPOU  VARCHAR(10);
   DECLARE @V_CDFILIAL  VARCHAR(04);
   DECLARE @V_IDLIMPSOL VARCHAR(01);
   DECLARE @V_IDLIMPCOL VARCHAR(01);
   DECLARE @V_IDLIMPAF  VARCHAR(01);
   DECLARE @V_SOLICITA_CDFILSOLI   VARCHAR(04);
   DECLARE @V_SOLICITA_CDFILLANCA  VARCHAR(04);
   DECLARE @V_SOLICITA_NRSOLICMP   VARCHAR(10);
   DECLARE @V_COLETAPR_CDFILIAL    VARCHAR(04);
   DECLARE @V_COLETAPR_NRCOLEPRECO VARCHAR(10);
   DECLARE @V_AUTOFORNE_CDFILDEST  VARCHAR(04);
   DECLARE @V_AUTOFORNE_CDFILLANC  VARCHAR(04);
   DECLARE @V_AUTOFORNE_NRAUTOFORN VARCHAR(10);
   DECLARE @V_SEGUNDO NUMERIC;
BEGIN
 SET @V_IDLIMPOU  = '0';
 SET @V_CDFILIAL  = ' ';
 SET @V_SEGUNDO   = 0;

 IF (@P_IDLIMPSOL = 'S') BEGIN

    DECLARE C_SOLICITA CURSOR FOR
       SELECT
           SOLICITA.CDFILSOLI,
           SOLICITA.CDFILLANCA,
           SOLICITA.NRSOLICMP
        FROM
           SOLICITA
        WHERE
          ((CHARINDEX(SOLICITA.CDFILSOLI, @P_CDFILLISTA) <> 0) OR @P_TCDFILIAL = 'T') AND
          SOLICITA.DTSOLCMP <= @P_DTLIMPSOL
        ORDER BY
           SOLICITA.CDFILSOLI
    OPEN C_SOLICITA;
    FETCH NEXT FROM C_SOLICITA INTO @V_SOLICITA_CDFILSOLI, @V_SOLICITA_CDFILLANCA, @V_SOLICITA_NRSOLICMP;
    WHILE (@@FETCH_STATUS = 0) BEGIN
       DELETE FROM MOVSOLEXT
       WHERE
          @V_SOLICITA_CDFILSOLI  = MOVSOLEXT.CDFILSOLEXT  AND
          @V_SOLICITA_CDFILLANCA = MOVSOLEXT.CDFILLANCEXT AND
          @V_SOLICITA_NRSOLICMP  = MOVSOLEXT.NRSOLIMOVEXT;

       DELETE FROM MOVOPSOL
       WHERE
          @V_SOLICITA_CDFILSOLI  = MOVOPSOL.CDFILSOLMOV AND
          @V_SOLICITA_CDFILLANCA = MOVOPSOL.CDFILLANMOV AND
          @V_SOLICITA_NRSOLICMP  = MOVOPSOL.NRSOLIMOV;

       DELETE FROM SOLICITA
       WHERE
          CDFILSOLI  = @V_SOLICITA_CDFILSOLI AND
          CDFILLANCA = @V_SOLICITA_CDFILLANCA AND
          NRSOLICMP  = @V_SOLICITA_NRSOLICMP;

       IF @V_CDFILIAL <> @V_SOLICITA_CDFILSOLI BEGIN
          SET @V_CDFILIAL = @V_SOLICITA_CDFILSOLI;
          INSERT INTO LOGLIMPEZA
            (DTLIMPDADOS, DSSISTLIMPEZ, NMOPERLIMPEZ,
             DTFINALIMPEZ, DSLIMPEZA)
          VALUES
             (GETDATE() + @V_SEGUNDO, @P_DSSISTEMA, @P_NMOPERADOR,
              @P_DTLIMPSOL, @P_DSLIMPSOL + ' ' + @V_SOLICITA_CDFILSOLI);

          SET @V_SEGUNDO = @V_SEGUNDO + 0.00001157407407;
          SET @V_IDLIMPOU = '1';
       END;

       FETCH NEXT FROM C_SOLICITA INTO @V_SOLICITA_CDFILSOLI, @V_SOLICITA_CDFILLANCA, @V_SOLICITA_NRSOLICMP;
    END;
    CLOSE C_SOLICITA;
    DEALLOCATE C_SOLICITA;

 END;

 SET @V_CDFILIAL  = ' ';
 SET @V_SEGUNDO   = 0;

 IF (@P_IDLIMPCOL = 'S') BEGIN

    DELETE FROM LOGCOLETAPR
    WHERE
       CDFILIALLOG = @P_CDCENTCMP AND
       DTCOLEPRLOG <= @P_DTLIMPCOT;

    DECLARE C_COLETAPR CURSOR FOR
       SELECT
           COLETAPR.CDFILIAL,
           COLETAPR.NRCOLEPRECO
        FROM
           COLETAPR
        WHERE
           CDFILIAL = @P_CDCENTCMP AND
           DTCOLEPREC <= @P_DTLIMPCOT
    OPEN C_COLETAPR;
    FETCH NEXT FROM C_COLETAPR INTO @V_COLETAPR_CDFILIAL, @V_COLETAPR_NRCOLEPRECO;
    WHILE (@@FETCH_STATUS = 0) BEGIN
       DELETE FROM ITMPREVLIST
       WHERE
          ITMPREVLIST.CDFILIAL    = @V_COLETAPR_CDFILIAL AND
          ITMPREVLIST.NRCOLEPRECO = @V_COLETAPR_NRCOLEPRECO;

       DELETE FROM COLETAPR
       WHERE
          CDFILIAL    = @V_COLETAPR_CDFILIAL AND
          NRCOLEPRECO = @V_COLETAPR_NRCOLEPRECO;
       IF @@ROWCOUNT <> 0 BEGIN
          SET @V_IDLIMPCOL = 'S';
       END;
       FETCH NEXT FROM C_COLETAPR INTO @V_COLETAPR_CDFILIAL, @V_COLETAPR_NRCOLEPRECO;
    END;
    CLOSE C_COLETAPR;
    DEALLOCATE C_COLETAPR;

    IF @V_IDLIMPCOL = 'S' BEGIN

       INSERT INTO LOGLIMPEZA
         (DTLIMPDADOS, DSSISTLIMPEZ, NMOPERLIMPEZ,
          DTFINALIMPEZ, DSLIMPEZA)
       VALUES
          (GETDATE(), @P_DSSISTEMA, @P_NMOPERADOR,
           @P_DTLIMPCOT, @P_DSLIMPCOT + ' ' + @P_CDCENTCMP);

       SET @V_IDLIMPOU = '2';
    END;
    DELETE FROM PREVLISTA
    WHERE
       NOT EXISTS(SELECT
                     ITMPREVLIST.CDFILIAL
                  FROM
                     ITMPREVLIST
                  WHERE
                     ITMPREVLIST.NRSEQPRELIST = PREVLISTA.NRSEQPRELIST AND
                     ITMPREVLIST.CDFILIAL     = PREVLISTA.CDFILIAL);
 END;

 SET @V_CDFILIAL  = ' ';

 IF (@P_IDLIMPAF = 'S') BEGIN
    DECLARE C_AUTOFORNE CURSOR FOR
       SELECT
           AUTOFORNE.CDFILDEST,
           AUTOFORNE.CDFILLANC,
           AUTOFORNE.NRAUTOFORN
        FROM
           AUTOFORNE
        WHERE
         ((CHARINDEX(CDFILDEST, @P_CDFILLISTA) <> 0) OR @P_TCDFILIAL = 'T') AND
         DTAUTOFORN <= @P_DTLIMPAF
        ORDER BY
           AUTOFORNE.CDFILDEST
    OPEN C_AUTOFORNE;
    FETCH NEXT FROM C_AUTOFORNE INTO @V_AUTOFORNE_CDFILDEST, @V_AUTOFORNE_CDFILLANC, @V_AUTOFORNE_NRAUTOFORN;
    WHILE (@@FETCH_STATUS = 0) BEGIN
       UPDATE ITEMPRODUTO
       SET
         ITEMPRODUTO.CDFILDEST   = NULL,
         ITEMPRODUTO.NRAUTOFORN  = NULL,
         ITEMPRODUTO.CDMARCA     = NULL,
         ITEMPRODUTO.DTPROGENTAF = NULL
       WHERE
         ITEMPRODUTO.CDFILDEST   = @V_AUTOFORNE_CDFILDEST  AND
         ITEMPRODUTO.CDFILIAL    = @V_AUTOFORNE_CDFILLANC  AND
         ITEMPRODUTO.NRAUTOFORN  = @V_AUTOFORNE_NRAUTOFORN;

       DELETE NFRELACAF
       WHERE
         NFRELACAF.CDFILDEST   = @V_AUTOFORNE_CDFILDEST  AND
         NFRELACAF.CDFILLANC   = @V_AUTOFORNE_CDFILLANC  AND
         NFRELACAF.NRAUTOFORN  = @V_AUTOFORNE_NRAUTOFORN;

       DELETE FROM AUTOFORNE
       WHERE
          CDFILDEST   = @V_AUTOFORNE_CDFILDEST AND
          CDFILLANC   = @V_AUTOFORNE_CDFILLANC AND
          NRAUTOFORN  = @V_AUTOFORNE_NRAUTOFORN;

       IF @V_CDFILIAL <> @V_AUTOFORNE_CDFILDEST BEGIN
          SET @V_CDFILIAL = @V_AUTOFORNE_CDFILDEST;
          INSERT INTO LOGLIMPEZA
            (DTLIMPDADOS, DSSISTLIMPEZ, NMOPERLIMPEZ,
             DTFINALIMPEZ, DSLIMPEZA)
          VALUES
             (GETDATE() + @V_SEGUNDO, @P_DSSISTEMA, @P_NMOPERADOR,
              @P_DTLIMPAF, @P_DSLIMPAF + ' ' + @V_AUTOFORNE_CDFILDEST);

          SET @V_IDLIMPOU = '4';
          SET @V_SEGUNDO = @V_SEGUNDO + 0.00001157407407;
       END;
       FETCH NEXT FROM C_AUTOFORNE INTO @V_AUTOFORNE_CDFILDEST, @V_AUTOFORNE_CDFILLANC, @V_AUTOFORNE_NRAUTOFORN;
    END;
    CLOSE C_AUTOFORNE;
    DEALLOCATE C_AUTOFORNE;
 END;
 SET @P_IDLIMPOU = @V_IDLIMPOU;
END
;
